size
产品支持情况
- Ascend 950PR/Ascend 950DT:支持
- Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
- Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
- Atlas 200I/500 A2 推理产品:不支持
- Atlas 推理系列产品AI Core:不支持
- Atlas 推理系列产品Vector Core:不支持
- Atlas 训练系列产品:不支持
功能说明
获取coalesced_group组内线程总数,与接口num_threads功能相同。
函数原型
C++
unsigned long long size() const
参数说明
无
返回值说明
coalesced_group组内线程总数。
约束说明
无
调用示例
SIMT编程场景:
C++using namespace cooperative_groups; __global__ void simt_kernel(...) { ... if (threadIdx.x % 2 == 0) { coalesced_group active = coalesced_threads(); unsigned long long thread_num = active.size(); // 返回16 } ... }SIMD与SIMT混合编程场景:
C++using namespace cooperative_groups; __simt_vf__ inline void simt_kernel(...) { ... if (threadIdx.x % 2 == 0) { coalesced_group active = coalesced_threads(); unsigned long long thread_num = active.size(); // 返回16 } ... }